@@ -2,19 +2,19 @@
 
 # Build zipfiles for ATK on Win32
 
-ZIP=/tmp/atk-0.12-`date +%Y%m%d`.zip
-DEVZIP=/tmp/atk-dev-0.12-`date +%Y%m%d`.zip
-cd /opt/gnome-2.0
+ZIP=/tmp/atk-1.0.0-`date +%Y%m%d`.zip
+DEVZIP=/tmp/atk-dev-1.0.0-`date +%Y%m%d`.zip
+cd /opt/gnome2
 
 rm $ZIP
 zip -r $ZIP -@ <<EOF
-lib/libatk-12.dll
+lib/libatk-1.0-0.dll
 EOF
 
 rm $DEVZIP
 zip -r $DEVZIP -@ <<EOF
 include/atk-1.0
-lib/libatk.dll.a
-lib/atk.lib
+lib/libatk-1.0.dll.a
+lib/atk-1.0.lib
 lib/pkgconfig/atk.pc
 EOF
