@@ -4,6 +4,10 @@
 #ifndef __ATK_ENUM_TYPES_H__
 #define __ATK_ENUM_TYPES_H__
 
+#include <glib-object.h>
+
+G_BEGIN_DECLS
+
 /* enumerations from "atkobject.h" */
 
 GType atk_role_get_type (void);
@@ -38,6 +42,8 @@ GType atk_key_event_type_get_type (void);
 GType atk_coord_type_get_type (void);
 #define ATK_TYPE_COORD_TYPE (atk_coord_type_get_type())
 
+G_END_DECLS
+
 #endif /* __ATK_ENUM_TYPES_H__ */
 
 /* Generated data ends here */
